@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1323 2008-07-25 19:13:48Z beerli $
+$Id: data.c 1446 2008-10-21 01:11:40Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -168,12 +168,9 @@ destroy_data (data_fmt * data)
   myfree(data->popnames);
   myfree(data->numind);
   myfree(data->numalleles);
-  myfree(data->seq->sites);
+  
   if(data->position!=NULL)
     myfree(data->position);
-  if(data->seq->links!=NULL)
-    myfree(data->seq->links);
-  myfree(data->seq);
   myfree(data->geo);
   myfree(data->lgeo);
   if(data->ogeo != NULL)
@@ -181,7 +178,6 @@ destroy_data (data_fmt * data)
       myfree(data->ogeo[0]);
       myfree(data->ogeo);
     }
-#ifdef TESTINGDATE
   // free sampledates
   for(locus=0;locus<data->loci;locus++)
     {
@@ -192,7 +188,6 @@ destroy_data (data_fmt * data)
     }
   myfree(data->sampledates[0]);
   myfree(data->sampledates);
-#endif
   myfree(data);
 }
  
@@ -216,20 +211,20 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
         break;
     case 'n': // read snp data
         read_sites (data);
-        data->seq->addon = 4;
+        data->seq[0]->addon = 4;
         break;
     case 'h': //read data from hapmap allele frequency files
       // there is no sites line in these files!
       for(locus=0;locus<data->loci;locus++)
-	data->seq->sites[locus] = 1;
-      data->seq->addon = 4;
+	data->seq[0]->sites[locus] = 1;
+      data->seq[0]->addon = 4;
         break;
     case 'u': // read panel snps with unknown panel??????
         read_sites (data);
-        data->seq->addon = 4;
+        data->seq[0]->addon = 4;
         break;
     default:
-        data->seq->fracchange = 1.0;
+        data->seq[0]->fracchange = 1.0;
         break;
     }
     if (options->progress)
@@ -251,9 +246,7 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
 
     read_uepfile (data, options, data->numpop);
 #endif
-#ifdef TESTINGDATE
     read_datefile(data, options, data->numpop);
-#endif
     if (options->progress)
         fprintf (stdout, "\n\n");
     init_data_structure3 (data);
@@ -297,7 +290,8 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
     if ((*data)->yy == NULL)
     {
         (*data)->yy = (char *****) mymalloc (sizeof (char ****) * numpop);
-        (*data)->seq = (seqmodel_fmt *) mycalloc (1, sizeof (seqmodel_fmt));
+        (*data)->seq = (seqmodel_fmt **) mycalloc (1, sizeof (seqmodel_fmt *));
+        (*data)->seq[0] = (seqmodel_fmt *) mycalloc (1, sizeof (seqmodel_fmt));
         (*data)->popnames =(char **) mymalloc (sizeof (char *) * numpop);
         (*data)->popnames[0] =(char *) mycalloc (numpop * LINESIZE,sizeof(char));
         (*data)->indnames = (char ***) mymalloc (sizeof (char **) * numpop);
@@ -312,8 +306,8 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
 	  (*data)->numind[pop] = (*data)->numind[0] + pop * loci;
 	  (*data)->numalleles[pop] =  (*data)->numalleles[0] + pop * loci;
         }
-        (*data)->seq->sites = (long *) mycalloc (1, sizeof (long) * loci);
-        (*data)->seq->links = (boolean *) mycalloc (1, sizeof (boolean) * loci);
+        (*data)->seq[0]->sites = (long *) mycalloc (1, sizeof (long) * loci);
+        (*data)->seq[0]->links = (boolean *) mycalloc (1, sizeof (boolean) * loci);
         (*data)->position = (long *) mycalloc (1, sizeof (long) * loci);
     }
     else
@@ -360,7 +354,7 @@ init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
                     (char **) mycalloc (1, sizeof (char *));
                 (*data)->yy[pop][ind][locus][0] =
                     (char *) mycalloc (1,
-                                     sizeof (char) * ((*data)->seq->sites[locus]+1));
+                                     sizeof (char) * ((*data)->seq[0]->sites[locus]+1));
             }
         }
     }
@@ -578,14 +572,15 @@ read_sites (data_fmt * data)
 	    if(isalpha(input[0]))
 	      {
 		read_word_delim(input,word,"=");
+		//strcpy(data->locusname,word);
 	      }
 	  }
 	if(linked)
-	  data->seq->links[locus] = TRUE;
+	  data->seq[0]->links[locus] = TRUE;
 	else
-	  data->seq->links[locus] = FALSE;
-        data->seq->sites[locus] = atoi (input);
-        if (data->seq->sites[locus] == 0)
+	  data->seq[0]->links[locus] = FALSE;
+        data->seq[0]->sites[locus] = atoi (input);
+        if (data->seq[0]->sites[locus] == 0)
         {
             warning ("This does look like sequence data\n");
             warning ("I just read a number of sites=0\n");
@@ -597,10 +592,10 @@ read_sites (data_fmt * data)
     while(input[0]=='#')
       FGETS(input,LINESIZE,data->infile);
     if(linked)
-      data->seq->links[locus] = TRUE;
+      data->seq[0]->links[locus] = TRUE;
     else
-      data->seq->links[locus] = FALSE;
-    data->seq->sites[locus] = atoi (input);
+      data->seq[0]->links[locus] = FALSE;
+    data->seq[0]->sites[locus] = atoi (input);
 
     myfree(input);
     myfree(word);
@@ -750,10 +745,14 @@ read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
       {
         // only one locus so we can use old scheme [see below]
         FGETS(input,LINESIZE,infile);
-	while(input[0]=='#')
+	//i=0;
+	//while(isspace(input[i] && input[i]!='\0'))
+	//      i++;
+	while(input[0]=='#')// || input[0] == '\n' | input[0] == '\0')
 	  {
 	    FGETS(input,LINESIZE,data->infile);
 	  }
+
         sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
                 data->popnames[pop]);
         data->numalleles[pop][0] = data->numind[pop][0]*genomes;
@@ -957,7 +956,7 @@ read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
 	  {
 	    fprintf(stdout,"%20li|",data->position[locus]);
 	  }
-	data->seq->sites[locus]=1;
+	data->seq[0]->sites[locus]=1;
 	read_word(infile,input);
 	label1 = input[0];;
 	read_word(infile,input);
@@ -1001,7 +1000,7 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
       {
     	fprintf(stdout,"%s|",data->indnames[pop][ind]);
       }
-    while (j < data->seq->sites[locus]
+    while (j < data->seq[0]->sites[locus]
             && !(options->interleaved && strchr(CRLF,charstate)))
     {
         charstate = getc (infile);
@@ -1035,13 +1034,19 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
             printf
             ("Last complete sequences was in population %li, individual %li and locus %li:\n%s",
              pop + 1, ind - 1, locus, data->indnames[pop][ind - 1]);
-            for (j = 0; j < data->seq->sites[locus]; j++)
+            for (j = 0; j < data->seq[0]->sites[locus]; j++)
                 printf ("%c", data->yy[pop][ind - 1][locus][0][j]);
             exit (EXIT_FAILURE);
         }
         data->yy[pop][ind][locus][0][j++] = charstate;
     }
     charstate = getc (infile); /* swallow the \n or \r */
+    while(charstate == '\n' || charstate == '\t' || charstate == ' ' || charstate == ';')
+      {
+	charstate = getc(infile);
+      }
+    if(charstate!='\n')
+      ungetc((int) charstate, infile);
 #ifndef MAC
 
     if (charstate == '\r')
@@ -1152,7 +1157,7 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
     long ind, baseread2 = 0, locus = 0;
     if (options->interleaved)
     {
-        while (baseread < data->seq->sites[0])
+        while (baseread < data->seq[0]->sites[0])
         {
             for (ind = 0; ind < data->numind[pop][0]; ind++)
             {
@@ -1173,7 +1178,7 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
         }
         if (options->interleaved)
         {
-            while (baseread < data->seq->sites[locus])
+            while (baseread < data->seq[0]->sites[locus])
             {
                 for (ind = 0; ind < data->numind[pop][locus]; ind++)
                 {
@@ -1714,7 +1719,7 @@ print_seq_ind (long locus, long pop, long ind, world_fmt * world,
     fprintf (world->outfile, "%-*.*s", (int) options->nmlength,
              (int) options->nmlength, data->indnames[pop][ind]);
     fprintf (world->outfile, " %c", data->yy[pop][ind][locus][0][0]);
-    for (site = 1; site < data->seq->sites[locus]; site++)
+    for (site = 1; site < data->seq[0]->sites[locus]; site++)
     {
         if ((site) % 60 == 0)
         {
