@@ -18,12 +18,12 @@
  M(1) = m(1)/mu, and M(2)= m(2)/mu
                                                                                                                
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: data.h 633 2007-03-06 04:14:07Z beerli $
+$Id: data.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
