@@ -17,7 +17,7 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h 1451 2008-10-22 23:48:56Z beerli $
+$Id: definitions.h 1458 2008-11-28 02:38:18Z beerli $
  
   *----------------------------------------------------------------
   */
@@ -60,6 +60,7 @@ $Id: definitions.h 1451 2008-10-22 23:48:56Z beerli $
 #define FGETS  myfgets
 
 #ifdef MPI
+#include <mpi.h>
 #define FPRINTF mpi_fprintf
 #else
 #define FPRINTF fprintf
@@ -322,7 +323,7 @@ typedef int boolean;
 #define DEFAULT_POPNMLENGTH  100L /* length of world names */
 #define NUMPOP 2L
 #define BURNINPERIOD 10000L
-#define SCALEINTERVAL 5L
+#define SCALEINTERVAL 2L
 #define DEFAULTALLOCSIZE 2L
 /* don't change below here ------------------------------------
    some other constants */
@@ -528,6 +529,8 @@ long chains is used */
 #define MICRO_THRESHOLD      200
 #define MAX_MICROSTEPNUM     200
 #define XBROWN_SIZE            3
+#define SINGLESTEP             1
+#define MULTISTEP              2
 /* sequence stuff*/
 #define MAXCATEGS              9
 #define MANYCATEGS             2
