@@ -8,8 +8,11 @@
 #include "bayes.h"
 #include "tools.h"
 #include "sighandler.h"
+#include "reporter.h"
 
 
+extern int myID;
+
 void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fmt *options, data_fmt *data)
 {
   char *input;
@@ -24,14 +27,23 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
       if(input[0] == '#' && strstr(input,"begin"))
 	{
 	  FGETS(input,LINESIZE,mdimfile);
+	  printf("%i>>>>>>> read from bayesallfile <<<<<<<<<<<<<<<<<<<<<<\n",myID);
 	  options->custm = myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm,input+9);
+	  printf("%i> custom       = %s\n",myID, options->custm);
 	  FGETS (input, LINESIZE, mdimfile);
 	  options->custm2 = myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm2,input+9);
+	  printf("%i> custom2      = %s\n",myID, options->custm2);
 	  FGETS (input, 1024, mdimfile);
 	  sscanf (input+3, "%li %li %li %li %li %i", &world->loci, &world->numpop,
 		  &world->numpop2, &tmp, &options->replicatenum,&recordedusem);
+	  printf("%i> loci         = %li\n",myID, world->loci);
+	  printf("%i> numpop       = %li\n",myID, world->numpop);
+	  printf("%i> numpop^2     = %li\n",myID, world->numpop2);
+	  printf("%i> replicate    = %li\n",myID, tmp);
+	  printf("%i> replicatenum = %li\n",myID, options->replicatenum);
+	  printf("%i> use_M        = %li\n",myID, (long) recordedusem);
 	  nrep = options->replicatenum;
 	  if (nrep == 0)
 	    nrep = 1;
@@ -44,6 +56,7 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
             data->popnames[pop] = (char *) mycalloc (1, sizeof (char) * LINESIZE);
 	    FGETS (input, LINESIZE, mdimfile);
 	    sscanf (input+3, "%s", data->popnames[pop]);
+	    printf("%i> population = %s\n",myID, data->popnames[pop]);
 	  }
 	done=TRUE;
 	}
@@ -54,6 +67,7 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
 			   sizeof (boolean) * (data->loci + 1));
   memset (data->skiploci, 0, sizeof (boolean) * (data->loci + 1));
   data->numpop = world->numpop;
+  printf("%i>>>>>>> end read from bayesallfile <<<<<<<<<<<<<<<<<<\n",myID);
   myfree(input);
 }
 			    
@@ -93,9 +107,11 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 {
 
   long *n = NULL;
-
+  long nnn=0;
+  const long nn = world->numpop2 + world->bayes->mu * world->loci + 1;// One is for Log(Prob(Data|Model)                                    
   long j0;
   long j;
+  long t;
   //  char *input;
   long step;
   long locus;
@@ -112,6 +128,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   MYREAL probg;
   MYREAL prior;
   MYREAL *params;
+  MYREAL lsum;
   char *input;
   char *inptr;
   bayes_fmt * bayes = world->bayes;
@@ -119,27 +136,28 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   long bin;
   MYREAL *delta = bayes->deltahist;
   //MYREAL *delta; 
- MYREAL *lowerbound;
+  MYREAL *lowerbound;
   MYREAL *upperbound;
+  MYREAL *autocorrelation;
+  MYREAL *ess;
   //  long binwidth;
   long numbins = 0;
   long numbinsall = 0;
   //MYREAL m;
   boolean *done;
   boolean recordedusem = options->usem;
+  long hc = world->options->heated_chains; 
 
   done = (boolean *) mycalloc(world->loci, sizeof(boolean));
   // params can be replaced by a single value for param and rate
   params = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
-  lowerbound = (MYREAL *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
-  upperbound = (MYREAL *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
-  //delta = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  autocorrelation = (MYREAL *) mycalloc(2 * world->loci * nn, sizeof(MYREAL));
+  ess = autocorrelation + world->loci * nn;
+  lowerbound = (MYREAL *) mycalloc(nn, sizeof(MYREAL));
+  upperbound = (MYREAL *) mycalloc(nn, sizeof(MYREAL));
+  //delta = (MYREAL *) mycalloc(nn-1, sizeof(MYREAL));
   n = (long *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(long));
-#ifdef BFDEBUG
   input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
-#else
-  input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
-#endif
   while(FGETS(input,SUPERLINESIZE,mdimfile) != EOF)
     {
       // grab the commentlines
@@ -164,6 +182,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	  treelength = atof(strsep(&inptr,"\t"));
 	  params[0] = post;
 	  params[1] = like;
+
 	  if(!done[locus])
 	    {
 
@@ -225,11 +244,42 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	      hist->minima[j0] = lowerbound[j0];
 	      hist->maxima[j0] = upperbound[j0];
 	      hist->results[numbins + bin] += 1.;
-
 	    }
+#ifdef BFDEBUG
+	  if(world->options->datatype == 'g')
+	    {
+	      for(t=0;t<hc;t++)
+		{
+		  world->bf[locus * hc + t] = atof(strsep(&inptr,"\t"));
+		}
+	      // dummy read of thermo sum up to this point
+	      lsum = atof(strsep(&inptr,"\t"));
+	      // harmonic mean: scaler contains the log value, hm contains 1.
+	      world->hmscale[locus] = atof(strsep(&inptr,"\t"));
+	      world->hm[locus] = 1.; 
+	      calculate_ess_frombayes (world, step, params, locus, &autocorrelation[locus*nn], &ess[locus*nn]);
+	    }
+#endif
 	}
-    } 
+    }
+  // reset the archiving machinery
+  memset(world->auto_archive,0, sizeof(MYREAL) * 2 * world->numpop2+options->bayesmurates * world->loci + 1);
+  nnn = 1;
+  for(j=0;j<world->loci;j++)
+    {
+      
+      for(t=0;t<nn; t++)
+	{
+	  // onepass mean of autocorrelation
+	  world->auto_archive[t] += (autocorrelation[j*nn + t] - world->auto_archive[t])/nnn;
+	  // summing ess values
+	  world->ess_archive[t] += ess[j*nn + t];
+	  printf("j=%li t=%li %f\n", j, t, world->ess_archive[t]);
+	}
+      nnn++;
+    }
   myfree(params);
+  myfree(autocorrelation);
   myfree(lowerbound);
   myfree(upperbound);
   myfree(n);
