@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1450 2008-10-22 02:40:52Z beerli $*/
+/* $Id: main.c 1461 2008-11-28 20:31:16Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -156,6 +156,8 @@ void
 condense_time (world_fmt * world, long *step, long *j,
                MYREAL * accepted, long *G, long *steps, long oldsteps,
                long rep);
+
+MYREAL sumbezier(long intervals, MYREAL x0, MYREAL y0, MYREAL x1, MYREAL y1, MYREAL x2, MYREAL y2);
 void calculate_BF(world_fmt **universe, option_fmt *options);
 
 long set_repkind (option_fmt * options);
@@ -486,7 +488,9 @@ main (int argc, char **argv)
 	get_mighistdata (EARTH, options);
 #endif
 	if(options->skyline && options->bayes_infer)
-	  print_expected_values(EARTH);       
+	  {
+	    print_expected_values(EARTH, options);       
+	  }
 	if(options->mighist || options->skyline)
 	  {
 	    print_event_values(EARTH);
@@ -554,16 +558,15 @@ main (int argc, char **argv)
     if (myID == MASTER)
       {
 #endif
-	// print marginal likelihoods
-	if(EARTH->options->bayes_infer && options->datatype!='g')
-	  {
-	    print_bayesfactor(EARTH->outfile, universe,options);
-	  }
-	
-	// printing of MCMC run characteristica
-	
+#ifdef BFDEBUG	
+	if(EARTH->options->bayes_infer)
+#else
 	if(EARTH->options->bayes_infer  && options->datatype!='g')
+#endif
 	  {
+	// print marginal likelihoods
+	    print_bayesfactor(EARTH->outfile, universe,options);
+	// printing of MCMC run characteristics
 	    fprintf(EARTH->outfile,"MCMC run characteristics\n");
 	    fprintf(EARTH->outfile,"========================\n\n");
 	    bayes_print_accept(EARTH->outfile,EARTH);
@@ -572,7 +575,7 @@ main (int argc, char **argv)
 #endif
 	    fprintf(EARTH->outfile,"Autocorrelation and Effective sample size\n");
 	    fprintf(EARTH->outfile,"-------------------------------------------------------------------\n\n");
-	    print_param_eff_size(EARTH->outfile,EARTH,EARTH->numpop2 + EARTH->bayes->mu * EARTH->loci + 1,2,EARTH->auto_archive, EARTH->ess_archive);
+	    print_bayes_ess(EARTH->outfile,EARTH,EARTH->numpop2 + EARTH->bayes->mu * EARTH->loci + 1,2,EARTH->auto_archive, EARTH->ess_archive);
 #ifdef PRETTY
 	    pdf_bayes_print_ess(EARTH);
 #endif
@@ -585,11 +588,15 @@ main (int argc, char **argv)
 	
 	if(EARTH->options->progress)
 	  {
+#ifdef BFDEBUG
+	    if(EARTH->options->bayes_infer)
+#else
 	    if(EARTH->options->bayes_infer && options->datatype!='g')
+#endif
 	      {
 		fprintf(stdout,"\nMCMC run characteristics: Autocorrelation and Effective sample size\n");
 		fprintf(stdout,"-------------------------------------------------------------------\n\n");
-		print_param_eff_size(stdout,EARTH,EARTH->numpop2+ EARTH->bayes->mu * EARTH->loci + 1,2,
+		print_bayes_ess(stdout,EARTH,EARTH->numpop2+ EARTH->bayes->mu * EARTH->loci + 1,2,
 				     EARTH->auto_archive, EARTH->ess_archive);
 		
 		print_bayesfactor(stdout, universe,options);
@@ -2203,9 +2210,11 @@ run_replicate (long locus,
         }
     }				//end runs
     //#ifndef MPI
+    // collect correlation information of a locus and stick it into the archive,
+    // the autocorrelation is averaged but the ess is summed up assuming that ll loci are independent
     if(EARTH->cold && EARTH->options->bayes_infer)
       {
-	  collect_eff_values(EARTH);
+	  collect_ess_values(EARTH);
       }
     //#endif
 }
@@ -2257,6 +2266,9 @@ void print_burnin_stop(FILE *file, world_fmt **universe, option_fmt * options)
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 {
+#ifdef MPI
+  static boolean done=FALSE;
+#endif
   long t;
   long hc = EARTH->options->heated_chains;
   long locus;
@@ -2272,7 +2284,6 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   MYREAL bfsum = 0.;
   MYREAL bfsum2 = 0.;
   MYREAL approxlsum = 0.;
-  MYREAL intercept = 0.;
   MYREAL hsum = 0.;
   MYREAL asum = 0.;
   MYREAL lsum;
@@ -2290,9 +2301,13 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 #ifdef MPI
 	  // the thermodynamic integration is reporting maxreplicate times too high values
 	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
-	  for(t=0; t < hc; t++)
+	  if(!done)
 	    {
-	      EARTH->bf[locus * hc + t] /= maxreplicate;
+	      for(t=0; t < hc; t++)
+		{
+		  EARTH->bf[locus * hc + t] /= maxreplicate;
+		}
+	      done=TRUE;
 	    }
 #endif
 	  for(t=1; t < hc; t++)
@@ -2301,15 +2316,23 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	      heat0 = 1./options->heat[t-1] ;
 	      heat1 = 1./options->heat[t];
 #else
-	      if(options->adaptiveheat)
+	      if(options->datatype!='g')
 		{
-		  heat0 = universe[t-1]->averageheat ;
-		  heat1 = universe[t]->averageheat;
+		  if(options->adaptiveheat)
+		    {
+		      heat0 = universe[t-1]->averageheat ;
+		      heat1 = universe[t]->averageheat;
+		    }
+		  else
+		    {
+		      heat0 = universe[t-1]->heat ;
+		      heat1 = universe[t]->heat;
+		    }
 		}
 	      else
 		{
-		  heat0 = universe[t-1]->heat ;
-		  heat1 = universe[t]->heat;
+		  heat0 = 1./options->heat[t-1];
+		  heat1 = 1./options->heat[t];
 		}
 #endif
 	      //Simpson's rule and trapezoidal are the same when I do only have function values at a and b
@@ -2326,23 +2349,31 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  // this is certainly rough, but in simulations with 3 populations one can see that with large number
 	  // of temperatures this looks reasonable, and one can approximate the integral more accurately with 
 	  // with only a few columns.
-	  intercept = (heat0 * EARTH->bf[locus * hc + t-1] - heat1 * EARTH->bf[locus * hc + t-2])/(heat0 - heat1);
-	  approxlsum = lsum + heat1 * ((EARTH->bf[locus * hc + t-1] + intercept) * 0.5);
+	  //	  intercept = (heat0 * EARTH->bf[locus * hc + t-1] - heat1 * EARTH->bf[locus * hc + t-2])/(heat0 - heat1);
+	  //approxlsum = lsum + heat1 * ((EARTH->bf[locus * hc + t-1] + intercept) * 0.5);
+	  // using Bezier to approximate nice curve between the last two points to mimick the curve that
+	  // can be found with 16 or 32 heated chains, handle points are calculated using adhoc decisions
+	  // (comaprison with 32 heated chains) using 0.8 of the interval for handle_y1 and the intercept
+	  // between the first and the second last point to calculate the handle_y2 see sumbezier()
+	  // for implementation. Currently this is not tunable.
+	  approxlsum = sumbezier(100, heat1, EARTH->bf[locus * hc + t-1], 
+				 heat0, EARTH->bf[locus * hc + t-2], 
+				 1.0, EARTH->bf[locus * hc]);
 #ifdef DEBUG
-	  fprintf(stdout,"Thermo[%li]=%f (%f) [%f]\n",locus, lsum, approxlsum, intercept);
+	  fprintf(stdout,"Thermo[%li]=%f (%f)\n",locus, lsum, approxlsum);
 #endif
 	  //	  bfsum += log(lsum) + EARTH->bfscale[locus];
 	  bfsum2 += approxlsum;
 
 	  bfsum += lsum; //+ EARTH->bfscale[locus];
 	}
-#ifdef NEWVERSION
-      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f (%f with approximation) %s\n", bfsum, bfsum2,  
-      	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
-#else
-      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f %s\n", bfsum,  
-      	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
-#endif
+      //#ifdef NEWVERSION
+      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f (%f with Bezier-approximation) %s\n", bfsum, bfsum2,  
+      	      options->adaptiveheat ? "(adaptive heating -> value may most likely be wrong)" : "");
+      //#else
+      //fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f %s\n", bfsum,  
+      //	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
+      //#endif
     }
   else
     {
@@ -2373,9 +2404,62 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   //(3) maybe strongly biased by large values\n\n\n");
 #ifdef PRETTY
   if(file==EARTH->outfile)
-    pdf_bayes_factor(EARTH, bfsum, hsum, asum, maxreplicate);
+    pdf_bayes_factor(EARTH, bfsum, bfsum2, hsum, asum, maxreplicate);
 #endif
 } 
+
+///
+/// integrates over a Bezier curve between two points
+/// calculates two handle points that are set to adhoc values
+/// so that the x values of the handle are the the x value of the lowest point
+/// and the y values are set to about 80% of the min to max interval for the left point
+/// and a value that is the the y value from ax + b where a is calculated from a 
+/// third point to the right and the second point, the third point is not used for the
+/// the Bezier curve otherwise
+MYREAL sumbezier(long intervals, MYREAL x0, MYREAL y0, MYREAL x1, MYREAL y1, MYREAL x2, MYREAL y2)
+{
+  const MYREAL inv_interval = 1./intervals;
+  const MYREAL sx0 = x0;
+  const MYREAL sx1 = x0;
+  const MYREAL sy0 = 0.2 * y0 + 0.8 * y1;
+  const MYREAL sy1 = (-x2 * y1 + x1 * y2)/(x1 - x2);
+  MYREAL t     = 0.0;
+  MYREAL t2    = 0.0;
+  MYREAL t3    = 0.0;
+  MYREAL onet  = 1.0;
+  MYREAL onet2 = 1.0;
+  MYREAL onet3 = 1.0;
+  MYREAL newx;
+  MYREAL newy;
+  MYREAL oldx;
+  MYREAL oldy;
+  MYREAL sum = 0.0;
+  // integrate over intervals between x0 and x1 and return sum
+  // intialize with t=0.0
+  oldx = x0;
+  oldy = y0;
+  fprintf(stdout,"\n\n%f %f %f %f %f %f\n",x2,y2,sx0,sy0, x0,y0);
+  for(t=inv_interval; t <= 1.0; t += inv_interval)
+    {
+      onet  = 1.0 - t;
+      onet2 = onet * onet;
+      onet3 = onet2 * onet;
+      onet2 *= 3.0 * t;
+      t2 = t * t;
+      t3 = t2 * t;
+      t2 *=  3.0 * onet;
+      //      newx = 3sx0 (1-t)^2 t + 3 sx1 (1-t) t^2 + (1-t)^3 x0 + t^3 x1
+      newx = sx0 * onet2 + sx1 * t2 + onet3 * x0 + t3 * x1;
+      newy = sy0 * onet2 + sy1 * t2 + onet3 * y0 + t3 * y1;
+      fprintf(stdout,"%f %f\n",newx,newy);
+      sum += (newx - oldx) * (newy + oldy)/2.;
+      oldx = newx;
+      oldy = newy;
+    }
+  fprintf(stdout,"%f %f %f %f\n\n\n",x1,y1,sx1,sy1);
+  return sum;
+}
+
   
 /// calculate values for the marginal likelihood using thermodynamic integration
 /// based on a method by Friel and Pettitt 2005
