@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1323 2008-07-25 19:13:48Z beerli $
+$Id: mcmc1.c 1464 2008-12-05 16:37:24Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -199,7 +199,7 @@ tree_update (world_fmt * world, long g)
     /*------------------------------------
       main loop: sliding down the tree  */
     slider = 0;
-#ifdef TESTINGDATE
+#ifdef DEBUG
     //printf("\nTime    Pop Type Lineages [mutrate=%f]\n",proposal->world->options->mu_rates[world->locus]);
 #endif
     while (nexttime <= endtime)
@@ -209,7 +209,7 @@ tree_update (world_fmt * world, long g)
 	   0) ? proposal->migr_table[proposal->migr_table_counter -
 				     1].from : proposal->origin->pop;
         proposal->time = age + eventtime (proposal, actualpop, tentry, &event);
-#ifdef TESTINGDATE
+#ifdef DEBUG
 	//	if(show==1)
 	//  {
 	//	 printf("%0.5f  %3li  %c  %3li",proposal->time,actualpop,event,tentry->lineages[0]);
@@ -291,9 +291,9 @@ tree_update (world_fmt * world, long g)
             world->root->tyme += proposal->time;
 	  }
         coalesce1p (proposal);
-	//#ifdef TESTINGDATE
+#ifdef DEBUG
 	//traverse_adjust(world->root->next->back, 1.0);
-	//#endif
+#endif
 	// record the time interval that was used for the lineage.
 	if(world->options->bayes_infer)
 	  {
@@ -422,8 +422,8 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
     (*proposal)->datatype = world->options->datatype;
     (*proposal)->sumtips = world->sumtips;
     (*proposal)->numpop = world->numpop;
-    (*proposal)->endsite = world->data->seq->endsite;
-    (*proposal)->fracchange = world->data->seq->fracchange;
+    (*proposal)->endsite = world->data->seq[0]->endsite;
+    (*proposal)->fracchange = world->data->seq[0]->fracchange;
     (*proposal)->param0 = world->param0;
     (*proposal)->root = world->root;
     (*proposal)->migration_model = world->options->migration_model;
@@ -463,8 +463,8 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
 
     if (strchr (SEQUENCETYPES, (*proposal)->datatype))
     {
-        allocate_xseq(&(*proposal)->xf, world->data->seq->endsite, world->options->rcategs);
-        allocate_xseq(&(*proposal)->xt, world->data->seq->endsite, world->options->rcategs);
+        allocate_xseq(&(*proposal)->xf, world->data->seq[0]->endsite, world->options->rcategs);
+        allocate_xseq(&(*proposal)->xt, world->data->seq[0]->endsite, world->options->rcategs);
     }
     else
     {
@@ -524,8 +524,8 @@ set_new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world
     (*proposal)->datatype = world->options->datatype;
     (*proposal)->sumtips = world->sumtips;
     (*proposal)->numpop = world->numpop;
-    (*proposal)->endsite = world->data->seq->endsite;
-    (*proposal)->fracchange = world->data->seq->fracchange;
+    (*proposal)->endsite = world->data->seq[0]->endsite;
+    (*proposal)->fracchange = world->data->seq[0]->fracchange;
     (*proposal)->param0 = world->param0;
     (*proposal)->root = world->root;
     (*proposal)->migration_model = world->options->migration_model;
@@ -1512,25 +1512,22 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
   //proposal changes when chain is stuck, to accept some new trees without
   //considering data to remove out of sticky area [hopefully]
   static long not_accepted = 0;
-#ifndef TESTINGDATE
-  static long disturb = LONG_MAX;
-  const long disturb_limit = proposal->world->sumtips;
-#endif
-  //
+
+  const long limit = MIGRATION_LIMIT * world->numpop;
+  
+  long rm  = 0L;
+  long rmc = rmigrcount (proposal);
+
+  MYREAL rr;
+  MYREAL expo;
+
 #ifdef UEP
     node *first;
 #endif
-    //boolean report = TRUE;
-    //long oldg = -1;
-    //MYREAL zz;
-    const long limit = MIGRATION_LIMIT * world->numpop;
-    MYREAL rr, expo;
-    long rm = 0L;
-    long rmc = rmigrcount (proposal);
-    //zz = world->heat;
-    rm =  proposal->migr_table_counter + proposal->migr_table_counter2 + world->migration_counts - rmc;
-    //if(world->heat < 0.001)
-    //  fprintf(stdout,"%i> heat=%f: %li = %li + %li + %li - %li | %li/%li : %li\n",myID, 1./world->heat, rm, proposal->migr_table_counter , proposal->migr_table_counter2 , world->migration_counts , rmc, proposal->world->node_collection_count, proposal->world->node_collection_allocated, proposal->world->node_collection_count - proposal->migr_table_counter - proposal->migr_table_counter2);
+
+    rm =  proposal->migr_table_counter + proposal->migr_table_counter2 
+      + world->migration_counts - rmc;
+    
     if (rm > limit)
     {
       // warning might disturb parallel runs and might be not really useful at all
@@ -1548,12 +1545,10 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
 #ifdef UEP
     if (world->options->uep)
     {
-        first =
-            first_uep2 (proposal->world->root->next->back,
-                        proposal->world->root->next->back,
-                        proposal->world->data->uepsites);
-        proposal->firstuep =
-            first_uep (first, proposal->world->root,
+        first = first_uep2 (proposal->world->root->next->back,
+			    proposal->world->root->next->back,
+			    proposal->world->data->uepsites);
+        proposal->firstuep = first_uep (first, proposal->world->root,
                        proposal->world->data->uepsites);
         proposal->ueplikelihood = pseudo_ueplikelihood (world, proposal);
         proposal->likelihood = pseudotreelikelihood (world, proposal);
@@ -1592,37 +1587,9 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
             return TRUE;
 	  }
     }
-    //printf("debug: always true\n");
-    //return TRUE;
-#ifndef TESTINGDATE
-    if(world->cold)
-      {
-	if(not_accepted++ > 10000)
-	  {
-	    disturb = 0;
-	    not_accepted = 0;
-	    warning("Escaping a sticky spot by accepting the next %li genealogy changes\n  (Log(P(D|G))= (previous=%f, new=%f))\n", disturb_limit,world->likelihood[g], proposal->likelihood);
-	    
-	  }
-	if(disturb < disturb_limit)
-	  {
-	    disturb++;
-	    fprintf(stdout,"%i> %li: Log(L)=%f\n",myID, disturb, proposal->likelihood);
-	    return TRUE;
-	  }
-	else
-	  {
-	    return FALSE;
-	  }
-      }
-    else
-      {
-	return FALSE;
-      }
-#else
-    //    printf("%i> %f\t %f\t %f\n",myID, world->heat, world->likelihood[g],proposal->likelihood);
+    if(world->options->prioralone)
+      return TRUE;
     return FALSE;
-#endif
 }
 
 long
