@@ -336,7 +336,7 @@ void calculate_event_values(duo **eventbins, long *eventbinnum, MYREAL eventinte
     if(bin > 10000 || bin < 0) // tooo many bins and it overflows probably 
                                //I should stop with some bins like 10000
       {
-        //error("bin is smaller than zero");
+        error("bin is smaller than zero or bigger than 10000");
         return;
       }
     diff = bin - lastbin;
@@ -377,7 +377,7 @@ void calculate_event_values(duo **eventbins, long *eventbinnum, MYREAL eventinte
 
 ///
 /// set up the event plot histogram containers, only when also the migration histograms are recorded
-/// tis functiosn needs to be called AFTER the setup_mighist() function
+/// this function needs to be called by setup_mighist() function
 void
 setup_mig_coal_events (world_fmt * world, option_fmt * options)
 {
@@ -462,6 +462,69 @@ void print_event_values_list(FILE *file, long locus, duo **eventbins, MYREAL eve
       } 
 }
 
+///
+/// read events from mighistfile and push them into the mighistlocus structure
+#define SOME_ELEMENTS 100
+void read_event_values_fromfile(FILE *file, world_fmt *world)
+{
+  long locus;
+  long pop;
+  long i;
+  MYREAL age;
+  char *input;
+  char *inptr;
+  duo **eventbins;
+  long *eventbinnum;
+  MYREAL eventbinsize;
+  long spacer=0;
+  long *allocsize;
+  input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
+  allocsize = (long *) mycalloc(world->numpop2*world->loci,sizeof(long));
+  for(i=0;i<world->numpop2*world->loci;i++)
+    {
+      allocsize[i]=1;
+    }
+  while(FGETS(input,SUPERLINESIZE,file) != EOF)
+    {
+      // grab the commentlines
+      while(input[0]=='#')
+	{
+	  FGETS(input,LINESIZE,file);
+	}
+      // read the mighistfile
+      if(input !=NULL)
+	{
+	  inptr = input;
+	  locus      = atol(strsep(&inptr,"\t"))-1;
+	  spacer = locus * world->numpop2;
+	  if(locus == -1)
+	    error("help");
+	  pop       = atol(strsep(&inptr,"\t"))-1;
+	  i          = atol(strsep(&inptr,"\t"))-1;
+	  age        = atof(strsep(&inptr,"\t"));
+
+	  eventbins =  world->mighistloci[locus].migeventbins;
+	  eventbinnum = world->mighistloci[locus].migeventbinnum;
+	  eventbinsize = world->mighistloci[locus].eventbinsize;
+
+	  if(i==0)
+	    {
+	      eventbinsize = 2 * age;
+	    }
+	  eventbinnum[pop] = i;
+	  if(allocsize[spacer + pop] < eventbinnum[pop])
+	    {
+	      allocsize[spacer + pop] += SOME_ELEMENTS;
+	      eventbins[pop] = myrealloc(eventbins[pop],allocsize[spacer + pop] * sizeof(duo));
+	    }
+	  eventbins[pop][i][0] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][1] = atof(strsep(&inptr,"\t"));
+	}
+    }
+  myfree(allocsize);
+}
+
+
 void print_event_values_tofile(FILE *file,  world_fmt *world)
 {
     long i;
@@ -662,13 +725,19 @@ void print_event_values(world_fmt * world)
 	sums0 = (MYREAL *) mycalloc(world->loci * world->numpop2 * 2,sizeof(MYREAL));
 	sums1 = sums0 + (world->loci * world->numpop2);
 
-        // prepare event histogram for printing and get total of observations
-        // for all (sums0) and for the mrcas only (sums1)
-        prepare_event_values(world,sums0, sums1);
-        
-        // print event to file
-        print_event_values_tofile(world->mighistfile, world);
-        
+	if(world->options->datatype != 'g')
+	  {
+	    // prepare event histogram for printing and get total of observations
+	    // for all (sums0) and for the mrcas only (sums1)
+	    prepare_event_values(world,sums0, sums1);
+	    
+	    // print event to file
+	    print_event_values_tofile(world->mighistfile, world);
+	  }
+	else
+	  {
+	    read_event_values_fromfile(world->mighistfile,world);
+	  }
         // print title to screen
         print_event_values_title(stdout, world->options->progress);
         
