@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1323 2008-07-25 19:13:48Z beerli $
+  $Id: migration.h 1453 2008-10-25 01:39:28Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -43,13 +43,20 @@ typedef float duo[2];
 #ifdef ALTIVEC
 typedef FloatVec sitelike;
 #else
+#ifdef VARMUT
+//  best model for condlike? chunks of numcategs * (condlike_site * numsites)
+//  accessing a single 1D array?
+//
+typedef MYREAL * sitelike; //this allows to tread each site as a different datatype with its own mutation model
+#else
 #ifdef GAP
 typedef MYREAL sitelike[5];
 #else
 typedef MYREAL sitelike[4];
-#endif
-#endif
-//typedef MYREAL *sitelike;
+#endif /*GAP*/
+#endif /*VARMUT*/
+#endif /*ALTIVEC*/
+
 typedef sitelike *ratelike;
 typedef ratelike *phenotype;
 typedef MYREAL contribarr[MAXCATEGS]; //!< \todo conditional likelihoods should change to 1-D vector
@@ -125,18 +132,51 @@ typedef union ueparray_fmt
 }
 ueparray_fmt;
 #endif
+#ifdef VARMUT
+typedef struct varmut_fmt
+{
+  //sequence model
+  MYREAL freqa, freqt, freqg, freqc;      //!< base frequencies
+  MYREAL freqr, freqy;                    //!< frequency of purins
+  MYREAL freqar, freqcy, freqgr, freqty;  //!< frequency of transitions
+  MYREAL aa, bb;                          //
+  long oldsite;                           //!< number of site patterns (raw, with SNP adjustment
+  long endsite;                           //!< number of site patterns 
+  MYREAL xi;                              //!< ratio of transitions
+  MYREAL xv;                              //!< ratio of transversions
+  MYREAL ttratio;                         //!< ration between transitions and transversions
+  MYREAL fracchange;                      //
+  //msat model
+
+  //allele model
+
+} varmut_fmt;
+#endif /*VARMUT*/
+
 
 /// sequence data structure
 typedef struct seqmodel_fmt
 {
-#ifdef ALTIVEC
-    FloatVec freq;
-    FloatVec freq_trans;
-#endif
-    
-  MYREAL freqa, freqt, freqg, freqc;      //!< base frequencies
-  MYREAL freqr, freqy;                    //!< frequency of purins
-  MYREAL freqar, freqcy, freqgr, freqty;  //!< frequency of transitions
+  // MYREAL freqa, freqt, freqg, freqc;      //!< base frequencies
+  // MYREAL freqr, freqy;                    //!< frequency of purins
+  // MYREAL freqar, freqcy, freqgr, freqty;  //!< frequency of transitions
+  // BASEFREQLENGTH is defined in definitions.h
+  MYREAL basefrequencies[BASEFREQLENGTH];             //!< base frequencies (a,c,g,t), gap, purins (r,y), transitions (ar,cy,gr,ty)
+  // rate matrix that should be in basefrequencies [g=nucleotide g, G=gap]
+  // pa pc pg pt pG
+  // rac rag rat raG rcg rct rcG rgt rgG rtG
+  // model vector (Huelsenbeck and Alfaro) augmented to allow the inclusion of gaps but using an additional class 0 --> set to zero.
+  //          abcdefghij
+  // no gaps:
+  // minimal: 1110110100
+  // JC/F81:  1110110100
+  // F84:     1110110100
+  // maximal: 1230450600
+  // full model:
+  // minimal: 1111111111
+  // JC/F81:  1110110100
+  // maximal: 123456789a
+  // 
   MYREAL aa, bb;                          //
   long oldsite;                           //!< number of site patterns (raw, with SNP adjustment
   long endsite;                           //!< number of site patterns 
@@ -192,7 +232,7 @@ typedef struct _data
     long numpop;            //!< number of populations
     long loci;              //!< number of loci
   long *position;           //!< position on chromosome [what to do with mutiple chromosomes?]
-    seqmodel_fmt *seq;      //!< sequence data model    
+    seqmodel_fmt **seq;      //!< sequence data model    
     MYREAL freq;            //
     MYREAL freqlast;        //
     char dlm;               //!< delimiter for allelic data
@@ -375,6 +415,7 @@ typedef struct _option
   char *bayesfilename;
   char *bayesmdimfilename;
 
+  boolean prioralone;
 
     char title[LINESIZE + 1];
     lratio_fmt *lratio;
@@ -401,6 +442,8 @@ typedef struct _option
     char dlm;
     long micro_stepnum;
     long micro_threshold;
+  int msat_option;
+  pair msat_tuning;
     MYREAL **steps;
     boolean interleaved;
     MYREAL seqerror;
@@ -727,6 +770,7 @@ typedef struct _worldoption
     MYREAL *lmu_rates;
   MYREAL *meanmu;
   MYREAL *inheritance_scalars;
+  boolean prioralone;
   MYREAL *heat;
   MYREAL *averageheat;
 #ifdef LONGSUM
@@ -784,6 +828,7 @@ typedef struct _worldoption
     long replicatenum;
     long *micro_threshold;
     long micro_stepnum;
+  pair msat_tuning;
     MYREAL ***steps;
     MYREAL *rrate;
     MYREAL *rate;
@@ -858,7 +903,7 @@ typedef struct _worlddata
   MYREAL *geo;
   MYREAL *lgeo;
   long *maxalleles;
-  seqmodel_fmt *seq;
+  seqmodel_fmt **seq;
   FILE *sumfile;
   MYREAL freq;
   MYREAL freqlast;
