@@ -14,12 +14,12 @@
  and finally helps to destroy itself.
                                                                                                                
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: options.h 729 2007-05-29 19:01:52Z beerli $
+$Id: options.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
