@@ -53,7 +53,7 @@ extern float pdf_loci_histogram(world_fmt *world);
 extern void pdf_bayes_print_accept(world_fmt *world);
 // print ESS and autocorrelation
 extern void pdf_bayes_print_ess(world_fmt *world);
-extern void pdf_bayes_factor(world_fmt *world, MYREAL tsum, MYREAL hsum, MYREAL asum, long maxreplicate);
+extern void pdf_bayes_factor(world_fmt *world, MYREAL tsum, MYREAL tsum2, MYREAL hsum, MYREAL asum, long maxreplicate);
 extern void pdf_burnin_stops(world_fmt *world, long maxreplicate);
 // MIGHIST output
 //extern void 
