@@ -6,7 +6,7 @@
  R e p o r t e r   R O U T I N E  reports things progress=True or verbose
  
  Peter Beerli
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2007 Peter Beerli, Tallahassee FL
@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1244 2008-05-13 13:42:33Z beerli $
+$Id: reporter.c 1458 2008-11-28 02:38:18Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -319,7 +319,7 @@ calc_allgelmanb (MYREAL *gelmanb, MYREAL *mc, MYREAL *chainmeans, long *nmeans,
 
 ///
 /// collect the autocorrelation values and the ESS values
-void collect_eff_values(world_fmt *world)
+void collect_ess_values(world_fmt *world)
 {
   static long n=1;
   const long nn = world->numpop2 + world->bayes->mu * world->loci + 1;// One is for Log(Prob(Data|Model)
@@ -329,10 +329,12 @@ void collect_eff_values(world_fmt *world)
 
   for(i=0;i<nn; i++)
     {
+      // onepass mean of autocorrelation
       world->auto_archive[i] += (world->autocorrelation[i] - world->auto_archive[i])/n;
+      // summing ess values
       world->ess_archive[i] += world->effective_sample[i];
     }
-  n++;
+  //  n++;
   //printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
 }
 
@@ -340,7 +342,7 @@ void collect_eff_values(world_fmt *world)
 
 ///
 /// prints the effective sample size and autocorrelation
-void print_param_eff_size(FILE *file, world_fmt *world, long numparam, int offset, 
+void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset, 
 			  MYREAL *autocorr, MYREAL *effsample)
 {
   long pa;
@@ -441,7 +443,8 @@ void print_param_eff_size(FILE *file, world_fmt *world, long numparam, int offse
 ///			   xn = xx[[n]];
 ///			   mn = mn  + (xn - mn)/n; 
 ///			   s = s + (xn - mo) (xn - mn);
-///			   r = r  + xo xn + mo (n mo  - x1 - xo) - mn ((n + 1) mn - x1 - xn);
+///KOFFI       r = r  + xo xn + mo (n mo  - x1 - xo) - mn ((n + 1) mn - x1 - xn);
+///PETER       r = r + (xo - mo)(xn-mn)
 ///			   mo = mn;
 ///			   n++;
 ///		     ];
@@ -526,10 +529,6 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
 		  x = world->options->mu_rates[world->locus];
 		}
 	    }
-	  //	  delta[j]  = x - mean[j];
-	  //mean[j]  += delta[j]/n;
-	  //S[j]     += delta[j] * (x - mean[j]);
-	  //v        += S[j];
 	  mean[j]   = x;
 	  S[j]      = 0.0;
 	  r[j]      = 0.0;
@@ -587,6 +586,141 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
   *variance =  (MYREAL) v / n;
   return *variance;
 }
+///
+/// this function mimics single_chain_var() but is used only in the reading bayesallfile function read_bayes_fromfile()
+/// taking into account that there may be a mixture of different loci and some variables are not where one expect them
+/// during the standard run
+void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locus, MYREAL *autoc, MYREAL *effsample)
+{
+  static double *mean;
+  static double *S;
+  static double *r;
+  static double *xold;
+  static double *xstart;
+  static boolean done=FALSE;
+  static long *n;
+  static long nn = 0;
+  static long nnbase = 0;
+  long i;
+  long j;
+  long z;
+  long start;
+
+  double x  = 0.0;
+  double xo = 0.0;
+  double x1 = 0.0;
+  double m  = 0.0;
+  double mo = 0.0;
+  //static double *v;
+  double *delta;
+  double temp;
+  if(!done)
+    {
+      nnbase = (world->numpop2 + world->bayes->mu * world->loci + 1);
+      nn = world->loci * nnbase;
+      n = mycalloc(world->loci,sizeof(long));
+      mean = mycalloc(nn,sizeof(double));
+      S    = mycalloc(nn,sizeof(double));
+      r    = mycalloc(nn,sizeof(double));
+      xold = mycalloc(nn,sizeof(double));
+      xstart = mycalloc(nn,sizeof(double));
+      done=TRUE;
+    }
+  // syntax so that an init really works
+  if(T==0)
+    return;
+
+  delta = mycalloc(nnbase,sizeof(double));
+  //handles BAYES or ML
+ start = (world->options->bayes_infer ? 0 : world->numpop2);
+  if(n[locus]==0) //initialization of mean calculator
+    {
+      n[locus] += 1;
+      for(i=start; i < nnbase; i++)
+	{
+	  if(i<world->numpop2)
+	    {
+	      if(world->bayes->map[i][1] == INVALID)
+		continue;
+	      else
+		{
+		  j  = world->bayes->map[i][1];
+		  z  = locus * nnbase + j;
+		  x  = params[j+2];
+		}
+	    }
+	  else
+	    {
+	      j = i;
+	      z  = locus * nnbase + j;
+	      if(j+1 == nnbase)
+		{
+		  x = params[1];
+		} 
+	      else
+		{
+		  x = world->options->mu_rates[locus];
+		}
+	    }
+	  mean[z]   = x;
+	  S[z]      = 0.0;
+	  r[z]      = 0.0;
+	  xstart[z] = x;
+	  xold[z] = x;
+	}
+      //  v = 0.0;
+      myfree(delta);
+    }
+  else
+    {
+      // n is at least 1
+      n[locus] += 1;
+      for(i=start; i < nnbase; i++)
+	{
+	  if(i<world->numpop2)
+	    {
+	      if(world->bayes->map[i][1] == INVALID)
+		continue;
+	      else
+		{
+		  j  = world->bayes->map[i][1];
+		  z  = locus * nnbase + j;
+		  x  = params[j+2];
+		}
+	    }
+	  else
+	    {
+	      j = i;
+	      z  = locus * nnbase + j;
+	      if(j+1 == nnbase)
+		{
+		  x = params[1];
+		} 
+	      else
+		{
+		  x = (double) world->options->mu_rates[locus];
+		}
+	    }
+	  xo        = xold[z];
+	  x1        = xstart[z];
+	  delta[z]  = x - mean[z];
+	  mo        = mean[z];
+	  mean[z]  += delta[z]/n[locus];
+	  m         = mean[z];
+	  S[z]     += delta[z] * (x - m);
+	  temp = xo * x + mo * (n[locus] * mo - x1 - xo) - m * ((n[locus]+1) * m - x1 - x);
+	  r[z]     += temp;
+	  autoc[z]  = S[z] > 0.0 ? (MYREAL) (r[z]/S[z]): (MYREAL) 1.0;
+	  effsample[z] = (MYREAL) (n[locus] * (1. - autoc[z])/(1. + autoc[z]));
+	  //v        += S[z];
+	  //printf("[%li] n=%li effsample=%g atoc=%g r=%g (%f) s=%g mean=%g\n", j, n[locus],effsample[j],autoc[j],r[j], temp, S[j],mean[j]);
+	  xold[z] = x;
+	}
+      myfree(delta);
+    }
+  //  *variance =  (MYREAL) v[locus] / n[locus];
+  //return *variance;
+}
 
 boolean max_ess(const MYREAL * ess, const long n, const MYREAL minimum)
 {
