@@ -6,7 +6,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     variation over time routines   R O U T I N E S
 
     Peter Beerli 2006, Tallahassee
-    beerli@scs.fsu.edu
+    beerli@fsu.edu
 
     Copyright 2006 Peter Beerli, Tallahassee
 
@@ -414,6 +414,70 @@ void print_expected_values_list(FILE *file, long locus, tetra **eventbins, MYREA
     } 
 }
 
+#define SOME_ELEMENTS 100
+void read_expected_values_fromfile(FILE *file, world_fmt *world)
+{
+  long locus;
+  long pop;
+  long i;
+  MYREAL age;
+  char *input;
+  char *inptr;
+  tetra **eventbins;
+  long *eventbinnum;
+  MYREAL eventbinsize;
+  long spacer;
+  long * allocsize;
+  allocsize = (long *) mycalloc(world->numpop2*world->loci,sizeof(long));
+  for(i=0;i<world->numpop2*world->loci;i++)
+    {
+      allocsize[i]=1;
+    }
+  input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
+  while(FGETS(input,SUPERLINESIZE,file) != EOF)
+    {
+      // grab the commentlines
+      while(input[0]=='#')
+	{
+	  FGETS(input,LINESIZE,file);
+	}
+      // read the skylinefile
+      if(input !=NULL)
+	{
+	  inptr = input;
+	  locus      = atol(strsep(&inptr,"\t"))-1;
+	  spacer = locus * world->numpop2;
+	  if(locus == -1)
+	    error("help");
+	  pop       = atol(strsep(&inptr,"\t"))-1;
+	  i          = atol(strsep(&inptr,"\t"))-1;
+	  age        = atof(strsep(&inptr,"\t"));
+
+	  eventbins =  world->mighistloci[locus].eventbins;
+	  eventbinnum = world->mighistloci[locus].eventbinnum;
+	  eventbinsize = world->mighistloci[locus].eventbinsize;
+	  eventbinnum[pop] = i;
+	  if(allocsize[spacer + pop] < eventbinnum[pop])
+	    {
+	      allocsize[spacer + pop] += SOME_ELEMENTS;
+	      eventbins[pop] = myrealloc(eventbins[pop], allocsize[spacer + pop] * sizeof(tetra));
+	    }
+
+	  if(i==0)
+	    {
+	      eventbinsize = 2 * age;
+	    }
+	  eventbins[pop][i][0] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][1] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][2] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][3] = 0;
+	  eventbins[pop][i][4] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][5] = atof(strsep(&inptr,"\t"));
+	}
+    }
+  myfree(allocsize);
+}
+
 void print_expected_values_tofile(FILE *file,  world_fmt *world)
 {
   long i;
@@ -434,7 +498,7 @@ void print_expected_values_tofile(FILE *file,  world_fmt *world)
   fprintf(file,"# produced by the program %s (http://popgen.csit.fsu.edu/migrate.hml)\n",
 	  MIGRATEVERSION);  
   fprintf(file,"# written by Peter Beerli 2006, Tallahassee,\n");
-  fprintf(file,"# if you have problems with this file please email to beerli@scs.fsu.edu\n");  
+  fprintf(file,"# if you have problems with this file please email to beerli@fsu.edu\n");  
   fprintf(file,"#\n");
   fprintf(file,"# Order of the parameters:\n");
   fprintf(file,"# Parameter-number Parameter\n");
@@ -477,7 +541,7 @@ void print_expected_values_tofile(FILE *file,  world_fmt *world)
 	      age = eventbinsize / 2.;
 	      for(i = 0; i < eventbinnum[pop]; i++)
 		{
-		  fprintf(file,"%li %li %li %10.10f %10.10f %10.10f %10.10f %10.10f %10.10f\n", 
+		  fprintf(file,"%li\t%li\t%li\t%10.10f\t%10.10f\t%10.10f\t%10.10f\t%10.10f\t%10.10f\n", 
 			  locus+1, pop+1, i+1, age, eventbins[pop][i][0], eventbins[pop][i][1],eventbins[pop][i][2],eventbins[pop][i][4],eventbins[pop][i][5]);
 		  age += eventbinsize;
 		}
@@ -630,17 +694,23 @@ void print_expected_values_title(FILE *file, boolean progress)
     }
 }
 
-void print_expected_values(world_fmt * world)
+void print_expected_values(world_fmt * world, option_fmt *options)
 {
   long locus;
   long sumloc = (world->loci > 1) ? 1 : 0;
   if(world->options->skyline)
     {
-      // prepare skyline histogram for printing
-      prepare_expected_values(world);
-      
-      // print skyline to file
-      print_expected_values_tofile(world->skylinefile, world);
+      if(world->options->datatype != 'g')
+	{
+	  // prepare skyline histogram for printing
+	  prepare_expected_values(world);
+	  // print skyline to file
+	  print_expected_values_tofile(world->skylinefile, world);
+	}
+      else
+	{
+	  read_expected_values_fromfile(world->skylinefile,world);
+	}
       // print title to screen
       print_expected_values_title(stdout, world->options->progress);
       // print title to ascii-outfile
@@ -648,14 +718,14 @@ void print_expected_values(world_fmt * world)
       // print content to stdout and to ascii - outfile
       for(locus=0; locus < world->loci+sumloc; locus++)
       	{
-	  	  if(world->options->progress)
-	     print_expected_values_list(stdout, locus, world->mighistloci[locus].eventbins, 
+	  if(world->options->verbose)
+	    print_expected_values_list(stdout, locus, world->mighistloci[locus].eventbins, 
 	    			       world->mighistloci[locus].eventbinsize, 
 	    			       world->mighistloci[locus].eventbinnum, world->numpop);
-	    print_expected_values_list(world->outfile, locus, world->mighistloci[locus].eventbins, 
+	  print_expected_values_list(world->outfile, locus, world->mighistloci[locus].eventbins, 
 	    			     world->mighistloci[locus].eventbinsize, 
 	    			     world->mighistloci[locus].eventbinnum, world->numpop);
-      }
+	}
 #ifdef PRETTY
 	  pdf_skyline_histogram(world->loci, world->numpop2,  world, FALSE);
 	  if(world->options->bayes_infer)
