@@ -6,7 +6,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     slice sampler routines   R O U T I N E S
 
     Peter Beerli 2006, Tallahassee
-    beerli@scs.fsu.edu
+    beerli@fsu.edu
 
     Copyright 2006-8 Peter Beerli, Tallahassee
 
