@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1444 2008-10-18 14:04:48Z beerli $
+$Id: tools.c 1458 2008-11-28 02:38:18Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -83,6 +83,8 @@ void onepass_mean_std_end(MYREAL *mean, MYREAL *std, long *n);
 //MYINLINE double fast_exp(double y) ;
 //MYINLINE float fast_log (float vval);
 
+MYREAL bezier(MYREAL x0, MYREAL y0, MYREAL x1, MYREAL y1);
+
 /* vector initialization */
 void doublevec1d (MYREAL **v, long size);
 void doublevec2d (MYREAL ***v, long size1, long size2);
@@ -587,7 +589,6 @@ void swap_node_collection(world_fmt * tthis, world_fmt * that)
   that->node_collection_allocated = tempallocated;
 }
 
-
 /*FILEMANIPULATION======================================================= */
 void
 init_files (world_fmt * world, data_fmt * data, option_fmt * options)
@@ -639,12 +640,28 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 
 		if (options->mighist)
 		  {
+		    if(options->datatype != 'g')
+		      {
 			openfile (&world->mighistfile, options->mighistfilename, "w+", NULL);
+		      }
+		    else
+		      {
+			openfile (&world->mighistfile, options->mighistfilename, "r+", NULL);
+		      }
 #ifdef MPI
 			setup_filehandle_db((void *) world->mighistfile, world, options, data);
 #endif			
 			if(options->skyline)
-			  openfile (&world->skylinefile, options->skylinefilename, "w+", NULL);
+			  {
+			    if(options->datatype != 'g')
+			      {
+				openfile (&world->skylinefile, options->skylinefilename, "w+", NULL);
+			      }
+			    else
+			      {
+				openfile (&world->skylinefile, options->skylinefilename, "r+", NULL);
+			      }
+			  }
 #ifdef MPI
 			setup_filehandle_db((void *) world->skylinefile, world, options, data);
 #endif			
@@ -843,7 +860,7 @@ translate (char *text, char from, char to)
     text[j] = '\0';
 }
 /// unpad from the end of the word until there is none of the
-/// specified characeter left
+/// specified character left
 void
 unpad (char *text, char removechars[])
 {
