@@ -9,12 +9,12 @@
  H E L P E R     R O U T I N E S 
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 1245 2008-05-13 21:59:23Z beerli $
+$Id: tools.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
