@@ -17,7 +17,7 @@
  and finally helps to destroy itself.
                                                                                                                
  Peter Beerli, started 1996
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2003 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
@@ -26,7 +26,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
 
-$Id: world.h 608 2007-02-17 23:32:53Z beerli $
+$Id: world.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
